Help

# OpenSesame Toolbox
Copyright Bob Rosbag (2015)

OpenSesame Toolbox offers two applications to supplement OpenSesame. OpenSesame Experiment Manager can manage, order and execute OpenSesame Experiments and create OpenSesame questionnaires. OpenSesame Questionnaire Processor can process OpenSesame multiple choice questionnaires by giving a summary of the scores.

## Usage GUI

This application package contains two applications:

#### OpenSesame Experiment Manager:

- Use the preselected Experiment folder or select your own custom folder.
- Select a log folder.
- Select language.
- You can drag and drop items to rearrange the order and (de)select the items.
- Additionally you can create new MC or Open Questionnaires.
- Use the Load and Save option to load/save your selection of questionnaires.

#### OpenSesame Questionnaire Processor:

- Select the folder containing the input files in the "Input folder" field. Only files with an extension of .csv will be processed.
- Select the destination folder.
- Press the 'Process' button and the processing process will commence.
- Additionally, custom adjustments can be made with the extra options.

## Usage CLI

It is possible to use OpenSesame Questionnaire Processor from the CLI:

`python opensesame-questionnaire-processor <source_folder> [<target_folder>]`

In linux where Python 2 is default, `python3` has to be used as cmd instead of `python` To use the CLI method it is required the questionnaires originate from the OpenSesame Experiment Manager or contain the same column names in the log files

## Licensing

OpenSesame Toolbox has been released under the terms of the GNU General Public License 3. You can find the full text of this license at http://www.gnu.org/licenses/gpl.txt

This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

See http://www.gnu.org/licenses/ for a copy of the GNU General Public License